@@ -11,6 +11,7 @@ import docker
 from git import Repo
 from giturlparse import parse
 from pytz import timezone
+import sh
 
 from ci_buildbot import __version__
 from ..settings import jinja_env
@@ -212,7 +213,11 @@ class GitChangelogMixin:
             changelog_commits.append(current)
             if current.hexsha == values['last_version_sha']:
                 break
-            current = current.parents[0]
+            try:
+                current = current.parents[0]
+            except IndexError:
+                # We really should never get here
+                break
         changelog = []
         authors = set()
         for commit in changelog_commits:
@@ -301,3 +306,10 @@ class DeployfishDeployMixin(AnnotationMixin):
     def annotate(self, values: Dict[str, str]):
         super().annotate(values)
         values['service'] = self.service
+
+
+class DeployfishTasksDeployMixin(DeployfishDeployMixin):
+
+    def annotate(self, values: Dict[str, str]):
+        super().annotate(values)
+        values['tasks'] = sh.deploy('related-tasks', self.service).split('\n')
